<?php declare(strict_types = 1);

namespace Drupal\activity_stream;

use Drupal\Core\Access\AccessResult;
use Drupal\Core\Entity\EntityAccessControlHandler;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Session\AccountInterface;

/**
 * Defines the access control handler for the activity entity type.
 *
 * phpcs:disable Drupal.Arrays.Array.LongLineDeclaration
 *
 * @see https://www.drupal.org/project/coder/issues/3185082
 */
final class ActivityAccessControlHandler extends EntityAccessControlHandler {

  /**
   * {@inheritdoc}
   */
  protected function checkAccess(EntityInterface $entity, $operation, AccountInterface $account): AccessResult {
    return match($operation) {
      'view' => AccessResult::allowedIfHasPermissions($account, ['view activity_stream_activity', 'administer activity_stream_activity'], 'OR'),
      'update' => AccessResult::allowedIfHasPermissions($account, ['edit activity_stream_activity', 'administer activity_stream_activity'], 'OR'),
      'delete' => AccessResult::allowedIfHasPermissions($account, ['delete activity_stream_activity', 'administer activity_stream_activity'], 'OR'),
      default => AccessResult::neutral(),
    };
  }

  /**
   * {@inheritdoc}
   */
  protected function checkCreateAccess(AccountInterface $account, array $context, $entity_bundle = NULL): AccessResult {
    return AccessResult::allowedIfHasPermissions($account, ['create activity_stream_activity', 'administer activity_stream_activity'], 'OR');
  }

}
